@@ -22,12 +22,13 @@ async def get_nh(id: int = choose().nhentai):
     img = parser['image_urls']
     print(f'Total image: {len(img)}')
 
-    neat_dir = title
+    neat_dir = split_name(__file__) + " - " + title
 
-    ## hapus semua tanda baca di neat_dir
+    ## remove all spaces with underscore in neat_dir
+    neat_dir = re.sub(r'\s+', '_', neat_dir)
 
     if not os.path.exists(neat_dir):
-        os.makedirs(neat_dir)
+        os.makedirs(neat_dir, 0o700)
 
     if len(os.listdir(neat_dir)) >= len(img):
         print("All images already downloaded! If you're doubt kindly remove this folder and re-download")
@@ -50,17 +51,21 @@ async def get_nh(id: int = choose().nhentai):
             if len(img) == len(os.listdir(neat_dir)):
                 print(
                     f'Successfully downloaded all images in {(time.time() - initial) / 60:.2f} minutes')
-                with open(neat_dir + '/tomoe.phtml', 'x') as f:
+                with open(neat_dir + '/tomoe.html', 'x') as f:
                     f.write('<html><center><body>')
                     f.write(f'<h1>{title}</h1>')
    
-                    for i in os.listdir(neat_dir)[:-1]:
-                        f.write(f'<img src="{neat_dir}/{i}"><p></p>')
+                    for i in img:
+                        ## get after last slash in img, example /1.jpg
+                        file = i.rsplit('/', 1)[-1]
+                        ## print(file)
+                        
+                        f.write(f'<img src="{neat_dir}/{file}"><p></p>')
                     f.write(f'{project()}')
                     f.write('</body></center></html>')
                     f.close()
 
-                    print(f'Static gallery saved to {neat_dir}/tomoe.phtml')
+                    print(f'Static gallery saved to {neat_dir}/tomoe.html')
                     print(f'Directory: {os.path.abspath(neat_dir)}')
 
         
@@ -70,7 +75,7 @@ async def get_nh(id: int = choose().nhentai):
 
                     if to_pdf == 'y':
                         try:
-                            source = open(f"{neat_dir}/tomoe.phtml")
+                            source = open(f"{neat_dir}/tomoe.html")
                             output = f"{neat_dir}/{parser['details']['id']}.pdf"
 
                             convert_html_to_pdf(source, output)
@@ -82,16 +87,16 @@ async def get_nh(id: int = choose().nhentai):
                                 
                     elif to_pdf == 'n':
                         print("Okay")
-                        os.remove(neat_dir + '/tomoe.phtml')
+                        os.remove(neat_dir + '/tomoe.html')
                         return
 
                     else:
                         print("Invalid input")
-                        os.remove(neat_dir + '/tomoe.phtml')
+                        os.remove(neat_dir + '/tomoe.html')
                         return
 
                 except TimeoutOccurred:
                     print("Timeout occurred")
-                    os.remove(neat_dir + '/tomoe.phtml')
+                    os.remove(neat_dir + '/tomoe.html')
                     exit()
 
